;;; zenirc-shop.el --- random shopping lists

;; Copyright (C) 1997 Noah S. Friedman

;; Author: Noah Friedman <friedman@prep.ai.mit.edu>
;; Maintainer: friedman@prep.ai.mit.edu
;; Keywords: zenirc, extensions, oink, shop
;; Created: 1997-02-04

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; if not, you can either send email to this
;; program's maintainer or write to: The Free Software Foundation,
;; Inc.; 59 Temple Place, Suite 330; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This module requires my `shop' shopping list generator.
;; See ftp://ftp.splode.com/pub/friedman/emacs-lisp/shop.el
;; or  ftp://alpha.gnu.ai.mit.edu/friedman/emacs-lisp/shop.el

;;; Code:

(require 'zenirc)
(require 'zenirc-trigger)
(require 'shop)          ; requires version 1.3 or later.

;; One this package is loaded, changing this variable is pointless
;; since the trigger registry doesn't look at it.
;; You will have to re-register the trigger to change the regexp.
(defconst zenirc-shop-default-regexp "\\bshop\\b")

(defconst zenirc-shop-item-count '(3 . 8)
  "*Number of shopping list items to display.
If this is a pair of numbers, it represents an upper and lower bound,
between which a random number of items will be generated.")

(defconst zenirc-shop-send-multiline nil
  "*If non-nil, send each shopping item in a separate message.
This is probably undesirable in most cases, as you can be kicked
off automatically for flooding.")

(defconst zenirc-shop-preamble "Here is your shopping list:")

(defun zenirc-shop ()
  (let* ((n zenirc-shop-item-count)
         (lines (shop-string-numbered-list
                 (if (consp n)
                     (shop-random-range (car n) (cdr n))
                   (shop-random n)))))
    (cond (zenirc-shop-send-multiline
           (cons zenirc-shop-preamble lines))
          (t
           (concat zenirc-shop-preamble " "
                   (mapconcat 'identity lines "; "))))))

(zenirc-trigger-register "shop" 'zenirc-shop zenirc-shop-default-regexp)

(provide 'zenirc-shop)

;;; zenirc-shop.el ends here
